@@ -155,27 +155,27 @@ extern SbkConverter **SbkPySide6_QtChartsTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTCHARTS_QLIST_INT_IDX                               = 0, // QList<int >
-    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 1, // QList<QObject* >
-    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 2, // QList<QByteArray >
-    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 3, // QList<QAction* >
-    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 4, // QList<QLegendMarker* >
-    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 5, // QList<QGraphicsItem* >
-    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 6, // QList<QRectF >
-    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 7, // QList<QAbstractAxis* >
-    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 8, // QList<QAbstractSeries* >
-    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 9, // QList<qreal >
-    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF >
-    SBK_QTCHARTS_QPAIR_QREAL_QREAL_IDX                       = 11, // QPair<qreal,qreal >
-    SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 12, // QHash<QXYSeries::PointConfiguration,QVariant >
-    SBK_QTCHARTS_QHASH_INT_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 13, // QHash<int,QHash< QXYSeries::PointConfiguration,QVariant > >
-    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 14, // QList<QPieSlice* >
-    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 15, // QList<QCandlestickSet* >
-    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 16, // QList<QBoxSet* >
-    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 17, // QList<QBarSet* >
-    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 18, // QList<QVariant >
-    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 19, // QList<QString >
-    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 20, // QMap<QString,QVariant >
+    SBK_QTCHARTS_QLIST_INT_IDX                               = 0, // QList<int>
+    SBK_QTCHARTS_QLIST_QOBJECTPTR_IDX                        = 1, // QList<QObject*>
+    SBK_QTCHARTS_QLIST_QBYTEARRAY_IDX                        = 2, // QList<QByteArray>
+    SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 3, // QList<QAction*>
+    SBK_QTCHARTS_QLIST_QLEGENDMARKERPTR_IDX                  = 4, // QList<QLegendMarker*>
+    SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 5, // QList<QGraphicsItem*>
+    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 6, // QList<QRectF>
+    SBK_QTCHARTS_QLIST_QABSTRACTAXISPTR_IDX                  = 7, // QList<QAbstractAxis*>
+    SBK_QTCHARTS_QLIST_QABSTRACTSERIESPTR_IDX                = 8, // QList<QAbstractSeries*>
+    SBK_QTCHARTS_QLIST_QREAL_IDX                             = 9, // QList<qreal>
+    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 10, // QList<QPointF>
+    SBK_QTCHARTS_STD_PAIR_QREAL_QREAL_IDX                    = 11, // std::pair<qreal,qreal>
+    SBK_QTCHARTS_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 12, // QHash<QXYSeries::PointConfiguration,QVariant>
+    SBK_QTCHARTS_QHASH_INT_QHASH_QXYSERIES_POINTCONFIGURATION_QVARIANT_IDX = 13, // QHash<int,QHash< QXYSeries::PointConfiguration,QVariant>>
+    SBK_QTCHARTS_QLIST_QPIESLICEPTR_IDX                      = 14, // QList<QPieSlice*>
+    SBK_QTCHARTS_QLIST_QCANDLESTICKSETPTR_IDX                = 15, // QList<QCandlestickSet*>
+    SBK_QTCHARTS_QLIST_QBOXSETPTR_IDX                        = 16, // QList<QBoxSet*>
+    SBK_QTCHARTS_QLIST_QBARSETPTR_IDX                        = 17, // QList<QBarSet*>
+    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 18, // QList<QVariant>
+    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 19, // QList<QString>
+    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 20, // QMap<QString,QVariant>
     SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 21
 };
 // Macros for type check
