@@ -14,6 +14,7 @@
 #include <pyside6_qtcore_python.h>
 
 // Bound library includes
+#include <QtConcurrent/qtaskbuilder.h>
 #include <QtConcurrent/qtconcurrentreducekernel.h>
 #include <QtConcurrent/qtconcurrentrunbase.h>
 #include <QtConcurrent/qtconcurrentthreadengine.h>
@@ -31,11 +32,12 @@ enum : int {
     SBK_QFUTUREWATCHER_QSTRING_IDX                           = 3,
     SBK_QFUTUREWATCHERVOID_IDX                               = 4,
     SBK_QFUTUREWATCHER_VOID_IDX                              = 4,
-    SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX                = 7,
-    SBK_QTCONCURRENT_REDUCEOPTION_IDX                        = 6,
+    SBK_QTCONCURRENT_FUTURERESULT_IDX                        = 6,
+    SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX                = 8,
+    SBK_QTCONCURRENT_REDUCEOPTION_IDX                        = 7,
     SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX                 = 0,
     SBK_QtConcurrentQTCONCURRENT_IDX                         = 5,
-    SBK_QtConcurrent_IDX_COUNT                               = 8
+    SBK_QtConcurrent_IDX_COUNT                               = 9
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtConcurrentTypes;
@@ -48,10 +50,10 @@ extern SbkConverter **SbkPySide6_QtConcurrentTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTCONCURRENT_QLIST_INT_IDX                           = 0, // QList<int >
-    SBK_QTCONCURRENT_QLIST_QVARIANT_IDX                      = 1, // QList<QVariant >
-    SBK_QTCONCURRENT_QLIST_QSTRING_IDX                       = 2, // QList<QString >
-    SBK_QTCONCURRENT_QMAP_QSTRING_QVARIANT_IDX               = 3, // QMap<QString,QVariant >
+    SBK_QTCONCURRENT_QLIST_INT_IDX                           = 0, // QList<int>
+    SBK_QTCONCURRENT_QLIST_QVARIANT_IDX                      = 1, // QList<QVariant>
+    SBK_QTCONCURRENT_QLIST_QSTRING_IDX                       = 2, // QList<QString>
+    SBK_QTCONCURRENT_QMAP_QSTRING_QVARIANT_IDX               = 3, // QMap<QString,QVariant>
     SBK_QtConcurrent_CONVERTERS_IDX_COUNT                    = 4
 };
 
@@ -81,6 +83,7 @@ template<> inline PyTypeObject *SbkType< ::QFutureWatcherQString >() { return re
 #if QT_CONFIG(future)
 template<> inline PyTypeObject *SbkType< ::QFutureWatcherVoid >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtConcurrentTypes[SBK_QFUTUREWATCHERVOID_IDX]); }
 #endif
+template<> inline PyTypeObject *SbkType< ::QtConcurrent::FutureResult >() { return SbkPySide6_QtConcurrentTypes[SBK_QTCONCURRENT_FUTURERESULT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QtConcurrent::ThreadFunctionResult >() { return SbkPySide6_QtConcurrentTypes[SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QtConcurrent::ReduceOption >() { return SbkPySide6_QtConcurrentTypes[SBK_QTCONCURRENT_REDUCEOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide6_QtConcurrentTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX]; }
