@@ -28,15 +28,18 @@
 #include <QtMultimedia/qmediaplayer.h>
 #include <QtMultimedia/qmediarecorder.h>
 #include <QtMultimedia/qmediatimerange.h>
+#include <QtMultimedia/qscreencapture.h>
 #include <QtMultimedia/qsoundeffect.h>
 #include <QtMultimedia/qvideoframe.h>
 #include <QtMultimedia/qvideoframeformat.h>
+#include <QtMultimedia/qwindowcapture.h>
 class QAudioBuffer;
 class QAudioInput;
 class QAudioOutput;
 class QAudioSink;
 class QAudioSource;
 class QCameraFormat;
+class QCapturableWindow;
 class QMediaCaptureSession;
 class QMediaDevices;
 class QVideoSink;
@@ -66,53 +69,58 @@ enum : int {
     SBK_QCAMERA_EXPOSUREMODE_IDX                             = 19,
     SBK_QCAMERA_WHITEBALANCEMODE_IDX                         = 24,
     SBK_QCAMERA_FEATURE_IDX                                  = 20,
-    SBK_QFLAGS_QCAMERA_FEATURE_IDX                           = 28,
+    SBK_QFLAGS_QCAMERA_FEATURE_IDX                           = 29,
     SBK_QCAMERA_IDX                                          = 17,
     SBK_QCAMERADEVICE_POSITION_IDX                           = 26,
     SBK_QCAMERADEVICE_IDX                                    = 25,
     SBK_QCAMERAFORMAT_IDX                                    = 27,
-    SBK_QIMAGECAPTURE_ERROR_IDX                              = 30,
-    SBK_QIMAGECAPTURE_QUALITY_IDX                            = 32,
-    SBK_QIMAGECAPTURE_FILEFORMAT_IDX                         = 31,
-    SBK_QIMAGECAPTURE_IDX                                    = 29,
-    SBK_QMEDIACAPTURESESSION_IDX                             = 33,
-    SBK_QMEDIADEVICES_IDX                                    = 34,
-    SBK_QMEDIAFORMAT_FILEFORMAT_IDX                          = 38,
-    SBK_QMEDIAFORMAT_AUDIOCODEC_IDX                          = 36,
-    SBK_QMEDIAFORMAT_VIDEOCODEC_IDX                          = 40,
-    SBK_QMEDIAFORMAT_CONVERSIONMODE_IDX                      = 37,
-    SBK_QMEDIAFORMAT_RESOLVEFLAGS_IDX                        = 39,
-    SBK_QMEDIAFORMAT_IDX                                     = 35,
-    SBK_QMEDIAMETADATA_KEY_IDX                               = 42,
-    SBK_QMEDIAMETADATA_IDX                                   = 41,
-    SBK_QMEDIAPLAYER_PLAYBACKSTATE_IDX                       = 47,
-    SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 46,
-    SBK_QMEDIAPLAYER_ERROR_IDX                               = 44,
-    SBK_QMEDIAPLAYER_LOOPS_IDX                               = 45,
-    SBK_QMEDIAPLAYER_IDX                                     = 43,
-    SBK_QMEDIARECORDER_QUALITY_IDX                           = 51,
-    SBK_QMEDIARECORDER_ENCODINGMODE_IDX                      = 49,
-    SBK_QMEDIARECORDER_RECORDERSTATE_IDX                     = 52,
-    SBK_QMEDIARECORDER_ERROR_IDX                             = 50,
-    SBK_QMEDIARECORDER_IDX                                   = 48,
-    SBK_QMEDIATIMERANGE_IDX                                  = 53,
-    SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 54,
-    SBK_QSOUNDEFFECT_LOOP_IDX                                = 56,
-    SBK_QSOUNDEFFECT_STATUS_IDX                              = 57,
-    SBK_QSOUNDEFFECT_IDX                                     = 55,
-    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 59,
-    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 60,
-    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 61,
-    SBK_QVIDEOFRAME_IDX                                      = 58,
-    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 67,
-    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 66,
-    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 68,
-    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 64,
-    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 65,
-    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 63,
-    SBK_QVIDEOFRAMEFORMAT_IDX                                = 62,
-    SBK_QVIDEOSINK_IDX                                       = 69,
-    SBK_QtMultimedia_IDX_COUNT                               = 70
+    SBK_QCAPTURABLEWINDOW_IDX                                = 28,
+    SBK_QIMAGECAPTURE_ERROR_IDX                              = 31,
+    SBK_QIMAGECAPTURE_QUALITY_IDX                            = 33,
+    SBK_QIMAGECAPTURE_FILEFORMAT_IDX                         = 32,
+    SBK_QIMAGECAPTURE_IDX                                    = 30,
+    SBK_QMEDIACAPTURESESSION_IDX                             = 34,
+    SBK_QMEDIADEVICES_IDX                                    = 35,
+    SBK_QMEDIAFORMAT_FILEFORMAT_IDX                          = 39,
+    SBK_QMEDIAFORMAT_AUDIOCODEC_IDX                          = 37,
+    SBK_QMEDIAFORMAT_VIDEOCODEC_IDX                          = 41,
+    SBK_QMEDIAFORMAT_CONVERSIONMODE_IDX                      = 38,
+    SBK_QMEDIAFORMAT_RESOLVEFLAGS_IDX                        = 40,
+    SBK_QMEDIAFORMAT_IDX                                     = 36,
+    SBK_QMEDIAMETADATA_KEY_IDX                               = 43,
+    SBK_QMEDIAMETADATA_IDX                                   = 42,
+    SBK_QMEDIAPLAYER_PLAYBACKSTATE_IDX                       = 48,
+    SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 47,
+    SBK_QMEDIAPLAYER_ERROR_IDX                               = 45,
+    SBK_QMEDIAPLAYER_LOOPS_IDX                               = 46,
+    SBK_QMEDIAPLAYER_IDX                                     = 44,
+    SBK_QMEDIARECORDER_QUALITY_IDX                           = 52,
+    SBK_QMEDIARECORDER_ENCODINGMODE_IDX                      = 50,
+    SBK_QMEDIARECORDER_RECORDERSTATE_IDX                     = 53,
+    SBK_QMEDIARECORDER_ERROR_IDX                             = 51,
+    SBK_QMEDIARECORDER_IDX                                   = 49,
+    SBK_QMEDIATIMERANGE_IDX                                  = 54,
+    SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 55,
+    SBK_QSCREENCAPTURE_ERROR_IDX                             = 57,
+    SBK_QSCREENCAPTURE_IDX                                   = 56,
+    SBK_QSOUNDEFFECT_LOOP_IDX                                = 59,
+    SBK_QSOUNDEFFECT_STATUS_IDX                              = 60,
+    SBK_QSOUNDEFFECT_IDX                                     = 58,
+    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 62,
+    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 63,
+    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 64,
+    SBK_QVIDEOFRAME_IDX                                      = 61,
+    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 70,
+    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 69,
+    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 71,
+    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 67,
+    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 68,
+    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 66,
+    SBK_QVIDEOFRAMEFORMAT_IDX                                = 65,
+    SBK_QVIDEOSINK_IDX                                       = 72,
+    SBK_QWINDOWCAPTURE_ERROR_IDX                             = 74,
+    SBK_QWINDOWCAPTURE_IDX                                   = 73,
+    SBK_QtMultimedia_IDX_COUNT                               = 75
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtMultimediaTypes;
@@ -125,26 +133,27 @@ extern SbkConverter **SbkPySide6_QtMultimediaTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTMULTIMEDIA_QLIST_INT_IDX                           = 0, // QList<int >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMERANGE_INTERVAL_IDX      = 1, // QList<QMediaTimeRange::Interval >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_KEY_IDX            = 2, // QList<QMediaMetaData::Key >
-    SBK_QTMULTIMEDIA_QHASH_QMEDIAMETADATA_KEY_QVARIANT_IDX   = 3, // QHash<QMediaMetaData::Key,QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_AUDIOCODEC_IDX       = 4, // QList<QMediaFormat::AudioCodec >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_FILEFORMAT_IDX       = 5, // QList<QMediaFormat::FileFormat >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_VIDEOCODEC_IDX       = 6, // QList<QMediaFormat::VideoCodec >
-    SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 7, // QList<QSize >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 8, // QList<QCameraFormat >
-    SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 9, // QList<QAudioFormat::SampleFormat >
-    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 10, // QList<QObject* >
-    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 11, // QList<QByteArray >
-    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 12, // QList<QAudioDevice >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 13, // QList<QCameraDevice >
-    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 14, // QList<QImageCapture::FileFormat >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 15, // QList<QMediaMetaData >
-    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 16, // QList<QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 17, // QList<QString >
-    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 18, // QMap<QString,QVariant >
-    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 19
+    SBK_QTMULTIMEDIA_QLIST_INT_IDX                           = 0, // QList<int>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMERANGE_INTERVAL_IDX      = 1, // QList<QMediaTimeRange::Interval>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_KEY_IDX            = 2, // QList<QMediaMetaData::Key>
+    SBK_QTMULTIMEDIA_QHASH_QMEDIAMETADATA_KEY_QVARIANT_IDX   = 3, // QHash<QMediaMetaData::Key,QVariant>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_AUDIOCODEC_IDX       = 4, // QList<QMediaFormat::AudioCodec>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_FILEFORMAT_IDX       = 5, // QList<QMediaFormat::FileFormat>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_VIDEOCODEC_IDX       = 6, // QList<QMediaFormat::VideoCodec>
+    SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 7, // QList<QSize>
+    SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 8, // QList<QCameraFormat>
+    SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 9, // QList<QAudioFormat::SampleFormat>
+    SBK_QTMULTIMEDIA_QLIST_QCAPTURABLEWINDOW_IDX             = 10, // QList<QCapturableWindow>
+    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 11, // QList<QObject*>
+    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 12, // QList<QByteArray>
+    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 13, // QList<QAudioDevice>
+    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 14, // QList<QCameraDevice>
+    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 15, // QList<QImageCapture::FileFormat>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 16, // QList<QMediaMetaData>
+    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 17, // QList<QVariant>
+    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 18, // QList<QString>
+    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 19, // QMap<QString,QVariant>
+    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 20
 };
 // Macros for type check
 
@@ -182,6 +191,7 @@ template<> inline PyTypeObject *SbkType< ::QCamera >() { return reinterpret_cast
 template<> inline PyTypeObject *SbkType< ::QCameraDevice::Position >() { return SbkPySide6_QtMultimediaTypes[SBK_QCAMERADEVICE_POSITION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QCAMERADEVICE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QCAMERAFORMAT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QCapturableWindow >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QCAPTURABLEWINDOW_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QImageCapture::Error >() { return SbkPySide6_QtMultimediaTypes[SBK_QIMAGECAPTURE_ERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QImageCapture::Quality >() { return SbkPySide6_QtMultimediaTypes[SBK_QIMAGECAPTURE_QUALITY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QImageCapture::FileFormat >() { return SbkPySide6_QtMultimediaTypes[SBK_QIMAGECAPTURE_FILEFORMAT_IDX]; }
@@ -208,6 +218,8 @@ template<> inline PyTypeObject *SbkType< ::QMediaRecorder::Error >() { return Sb
 template<> inline PyTypeObject *SbkType< ::QMediaRecorder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QMEDIARECORDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaTimeRange >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QMEDIATIMERANGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaTimeRange::Interval >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QMEDIATIMERANGE_INTERVAL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QScreenCapture::Error >() { return SbkPySide6_QtMultimediaTypes[SBK_QSCREENCAPTURE_ERROR_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QScreenCapture >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QSCREENCAPTURE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect::Loop >() { return SbkPySide6_QtMultimediaTypes[SBK_QSOUNDEFFECT_LOOP_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect::Status >() { return SbkPySide6_QtMultimediaTypes[SBK_QSOUNDEFFECT_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QSOUNDEFFECT_IDX]); }
@@ -223,6 +235,8 @@ template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorTransfer >()
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorRange >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoSink >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QVIDEOSINK_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QWindowCapture::Error >() { return SbkPySide6_QtMultimediaTypes[SBK_QWINDOWCAPTURE_ERROR_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QWindowCapture >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QWINDOWCAPTURE_IDX]); }
 
 } // namespace Shiboken
 
