@@ -206,39 +206,39 @@ extern SbkConverter **SbkPySide6_QtNetworkTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTNETWORK_QLIST_INT_IDX                              = 0, // QList<int >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 1, // QList<QSslCertificate >
-    SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray >
-    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 3, // QMap<QByteArray,QVariant >
-    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 4, // QList<QSslCipher >
-    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 5, // QList<QSslEllipticCurve >
-    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 6, // QList<QNetworkProxy >
-    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 7, // QList<QNetworkAddressEntry >
-    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 8, // QList<QHostAddress >
-    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 9, // QList<QNetworkInterface >
-    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 10, // QHash<QNetworkRequest::Attribute,QVariant >
-    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 11, // std::pair<QByteArray,QByteArray >
-    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 12, // QList<std::pair< QByteArray,QByteArray > >
-    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 13, // QHash<QString,QVariant >
-    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 14, // QList<QObject* >
-    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 15, // QList<QNetworkCookie >
-    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 16, // QList<QHstsPolicy >
-    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 17, // QList<QSslError >
-    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 18, // QList<QDnsDomainNameRecord >
-    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 19, // QList<QDnsHostAddressRecord >
-    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 20, // QList<QDnsMailExchangeRecord >
-    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 21, // QList<QDnsServiceRecord >
-    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 22, // QList<QDnsTextRecord >
-    SBK_QTNETWORK_QPAIR_QHOSTADDRESS_INT_IDX                 = 23, // QPair<QHostAddress,int >
-    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 24, // QList<QString >
-    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 25, // QList<QSsl::ImplementedClass >
-    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 26, // QList<QOcspResponse >
-    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 27, // QList<QSsl::SupportedFeature >
-    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 28, // QList<QSsl::SslProtocol >
-    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 29, // QList<QSslCertificateExtension >
-    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 30, // QMultiMap<QSsl::AlternativeNameEntryType,QString >
-    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 31, // QList<QVariant >
-    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 32, // QMap<QString,QVariant >
+    SBK_QTNETWORK_QLIST_INT_IDX                              = 0, // QList<int>
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATE_IDX                  = 1, // QList<QSslCertificate>
+    SBK_QTNETWORK_QLIST_QBYTEARRAY_IDX                       = 2, // QList<QByteArray>
+    SBK_QTNETWORK_QMAP_QBYTEARRAY_QVARIANT_IDX               = 3, // QMap<QByteArray,QVariant>
+    SBK_QTNETWORK_QLIST_QSSLCIPHER_IDX                       = 4, // QList<QSslCipher>
+    SBK_QTNETWORK_QLIST_QSSLELLIPTICCURVE_IDX                = 5, // QList<QSslEllipticCurve>
+    SBK_QTNETWORK_QLIST_QNETWORKPROXY_IDX                    = 6, // QList<QNetworkProxy>
+    SBK_QTNETWORK_QLIST_QNETWORKADDRESSENTRY_IDX             = 7, // QList<QNetworkAddressEntry>
+    SBK_QTNETWORK_QLIST_QHOSTADDRESS_IDX                     = 8, // QList<QHostAddress>
+    SBK_QTNETWORK_QLIST_QNETWORKINTERFACE_IDX                = 9, // QList<QNetworkInterface>
+    SBK_QTNETWORK_QHASH_QNETWORKREQUEST_ATTRIBUTE_QVARIANT_IDX = 10, // QHash<QNetworkRequest::Attribute,QVariant>
+    SBK_QTNETWORK_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX         = 11, // std::pair<QByteArray,QByteArray>
+    SBK_QTNETWORK_QLIST_STD_PAIR_QBYTEARRAY_QBYTEARRAY_IDX   = 12, // QList<std::pair< QByteArray,QByteArray>>
+    SBK_QTNETWORK_QHASH_QSTRING_QVARIANT_IDX                 = 13, // QHash<QString,QVariant>
+    SBK_QTNETWORK_QLIST_QOBJECTPTR_IDX                       = 14, // QList<QObject*>
+    SBK_QTNETWORK_QLIST_QNETWORKCOOKIE_IDX                   = 15, // QList<QNetworkCookie>
+    SBK_QTNETWORK_QLIST_QHSTSPOLICY_IDX                      = 16, // QList<QHstsPolicy>
+    SBK_QTNETWORK_QLIST_QSSLERROR_IDX                        = 17, // QList<QSslError>
+    SBK_QTNETWORK_QLIST_QDNSDOMAINNAMERECORD_IDX             = 18, // QList<QDnsDomainNameRecord>
+    SBK_QTNETWORK_QLIST_QDNSHOSTADDRESSRECORD_IDX            = 19, // QList<QDnsHostAddressRecord>
+    SBK_QTNETWORK_QLIST_QDNSMAILEXCHANGERECORD_IDX           = 20, // QList<QDnsMailExchangeRecord>
+    SBK_QTNETWORK_QLIST_QDNSSERVICERECORD_IDX                = 21, // QList<QDnsServiceRecord>
+    SBK_QTNETWORK_QLIST_QDNSTEXTRECORD_IDX                   = 22, // QList<QDnsTextRecord>
+    SBK_QTNETWORK_STD_PAIR_QHOSTADDRESS_INT_IDX              = 23, // std::pair<QHostAddress,int>
+    SBK_QTNETWORK_QLIST_QSTRING_IDX                          = 24, // QList<QString>
+    SBK_QTNETWORK_QLIST_QSSL_IMPLEMENTEDCLASS_IDX            = 25, // QList<QSsl::ImplementedClass>
+    SBK_QTNETWORK_QLIST_QOCSPRESPONSE_IDX                    = 26, // QList<QOcspResponse>
+    SBK_QTNETWORK_QLIST_QSSL_SUPPORTEDFEATURE_IDX            = 27, // QList<QSsl::SupportedFeature>
+    SBK_QTNETWORK_QLIST_QSSL_SSLPROTOCOL_IDX                 = 28, // QList<QSsl::SslProtocol>
+    SBK_QTNETWORK_QLIST_QSSLCERTIFICATEEXTENSION_IDX         = 29, // QList<QSslCertificateExtension>
+    SBK_QTNETWORK_QMULTIMAP_QSSL_ALTERNATIVENAMEENTRYTYPE_QSTRING_IDX = 30, // QMultiMap<QSsl::AlternativeNameEntryType,QString>
+    SBK_QTNETWORK_QLIST_QVARIANT_IDX                         = 31, // QList<QVariant>
+    SBK_QTNETWORK_QMAP_QSTRING_QVARIANT_IDX                  = 32, // QMap<QString,QVariant>
     SBK_QtNetwork_CONVERTERS_IDX_COUNT                       = 33
 };
 // Macros for type check
