@@ -155,21 +155,21 @@ extern SbkConverter **SbkPySide6_QtOpenGLTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTOPENGL_QLIST_INT_IDX                               = 0, // QList<int >
-    SBK_QTOPENGL_QPAIR_INT_INT_IDX                           = 1, // QPair<int,int >
-    SBK_QTOPENGL_QPAIR_FLOAT_FLOAT_IDX                       = 2, // QPair<float,float >
-    SBK_QTOPENGL_QPAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 3, // QPair<QOpenGLTexture::Filter,QOpenGLTexture::Filter >
-    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 4, // QList<QSize >
-    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 5, // QList<unsigned int >
-    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 6, // QList<QObject* >
-    SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 7, // QList<QByteArray >
-    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 8, // QList<uint64_t >
-    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 9, // QList<float >
-    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 10, // QList<QOpenGLShader* >
-    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 11, // QList<QOpenGLDebugMessage >
-    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 12, // QList<QVariant >
-    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 13, // QList<QString >
-    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 14, // QMap<QString,QVariant >
+    SBK_QTOPENGL_QLIST_INT_IDX                               = 0, // QList<int>
+    SBK_QTOPENGL_STD_PAIR_INT_INT_IDX                        = 1, // std::pair<int,int>
+    SBK_QTOPENGL_STD_PAIR_FLOAT_FLOAT_IDX                    = 2, // std::pair<float,float>
+    SBK_QTOPENGL_STD_PAIR_QOPENGLTEXTURE_FILTER_QOPENGLTEXTURE_FILTER_IDX = 3, // std::pair<QOpenGLTexture::Filter,QOpenGLTexture::Filter>
+    SBK_QTOPENGL_QLIST_QSIZE_IDX                             = 4, // QList<QSize>
+    SBK_QTOPENGL_QLIST_UNSIGNEDINT_IDX                       = 5, // QList<unsigned int>
+    SBK_QTOPENGL_QLIST_QOBJECTPTR_IDX                        = 6, // QList<QObject*>
+    SBK_QTOPENGL_QLIST_QBYTEARRAY_IDX                        = 7, // QList<QByteArray>
+    SBK_QTOPENGL_QLIST_UINT64_T_IDX                          = 8, // QList<uint64_t>
+    SBK_QTOPENGL_QLIST_FLOAT_IDX                             = 9, // QList<float>
+    SBK_QTOPENGL_QLIST_QOPENGLSHADERPTR_IDX                  = 10, // QList<QOpenGLShader*>
+    SBK_QTOPENGL_QLIST_QOPENGLDEBUGMESSAGE_IDX               = 11, // QList<QOpenGLDebugMessage>
+    SBK_QTOPENGL_QLIST_QVARIANT_IDX                          = 12, // QList<QVariant>
+    SBK_QTOPENGL_QLIST_QSTRING_IDX                           = 13, // QList<QString>
+    SBK_QTOPENGL_QMAP_QSTRING_QVARIANT_IDX                   = 14, // QMap<QString,QVariant>
     SBK_QtOpenGL_CONVERTERS_IDX_COUNT                        = 15
 };
 // Macros for type check
