@@ -60,6 +60,117 @@ QArgData qArgDataFromPyType(PyObject *t)
 }
 // @snippet qarg_helper
 
+// @snippet settings-value-helpers
+// Convert a QVariant to a desired primitive type
+static PyObject *convertToPrimitiveType(const QVariant &out, int metaTypeId)
+{
+    switch (metaTypeId) {
+    case QMetaType::QByteArray:
+        return PyBytes_FromString(out.toByteArray().constData());
+    case QMetaType::QString:
+        return PyUnicode_FromString(out.toByteArray().constData());
+    case QMetaType::Short:
+    case QMetaType::Long:
+    case QMetaType::LongLong:
+    case QMetaType::UShort:
+    case QMetaType::ULong:
+    case QMetaType::ULongLong:
+    case QMetaType::Int:
+    case QMetaType::UInt:
+        return PyLong_FromDouble(out.toFloat());
+    case QMetaType::Double:
+    case QMetaType::Float:
+    case QMetaType::Float16:
+        return PyFloat_FromDouble(out.toFloat());
+    case QMetaType::Bool:
+        if (out.toBool()) {
+            Py_INCREF(Py_True);
+            return Py_True;
+        }
+        Py_INCREF(Py_False);
+        return Py_False;
+    default:
+        break;
+    }
+    return nullptr;
+}
+
+// Helper for QSettings::value() to convert a value to the desired type
+static PyObject *settingsTypeCoercion(const QVariant &out, PyTypeObject *typeObj)
+{
+    if (typeObj == &PyList_Type) {
+        // Convert any string, etc, to a list of 1 element
+        if (auto *primitiveValue = convertToPrimitiveType(out, out.typeId())) {
+            PyObject *list = PyList_New(1);
+            PyList_SET_ITEM(list, 0, primitiveValue);
+            return list;
+        }
+
+        const QByteArray out_ba = out.toByteArray();
+        if (out_ba.isEmpty())
+            return PyList_New(0);
+
+        const QByteArrayList valuesList = out_ba.split(',');
+        const Py_ssize_t valuesSize = valuesList.size();
+        PyObject *list = PyList_New(valuesSize);
+        for (Py_ssize_t i = 0; i < valuesSize; ++i) {
+            PyObject *item = PyUnicode_FromString(valuesList.at(i).constData());
+            PyList_SET_ITEM(list, i, item);
+        }
+        return list;
+    }
+
+    if (typeObj == &PyBytes_Type)
+        return convertToPrimitiveType(out, QMetaType::QByteArray);
+    if (typeObj == &PyUnicode_Type)
+        return convertToPrimitiveType(out, QMetaType::QString);
+    if (typeObj == &PyLong_Type)
+        return convertToPrimitiveType(out, QMetaType::Int);
+    if (typeObj == &PyFloat_Type)
+        return convertToPrimitiveType(out, QMetaType::Double);
+    if (typeObj == &PyBool_Type)
+        return convertToPrimitiveType(out, QMetaType::Bool);
+
+    // TODO: PyDict_Type and PyTuple_Type
+    PyErr_SetString(PyExc_TypeError,
+                    "Invalid type parameter.\n"
+                    "\tUse 'list', 'bytes', 'str', 'int', 'float', 'bool', "
+                    "or a Qt-derived type");
+    return nullptr;
+}
+
+static bool isEquivalentSettingsType(PyTypeObject *typeObj, int metaTypeId)
+{
+    switch (metaTypeId) {
+    case QMetaType::QVariantList:
+    case QMetaType::QStringList:
+        return typeObj == &PyList_Type;
+    case QMetaType::QByteArray:
+        return typeObj == &PyBytes_Type;
+    case QMetaType::QString:
+        return typeObj == &PyUnicode_Type;
+    case QMetaType::Short:
+    case QMetaType::Long:
+    case QMetaType::LongLong:
+    case QMetaType::UShort:
+    case QMetaType::ULong:
+    case QMetaType::ULongLong:
+    case QMetaType::Int:
+    case QMetaType::UInt:
+        return typeObj == &PyLong_Type;
+    case QMetaType::Double:
+    case QMetaType::Float:
+    case QMetaType::Float16:
+        return typeObj == &PyFloat_Type;
+    case QMetaType::Bool:
+        return typeObj == &PyBool_Type;
+    default:
+        break;
+    }
+    return false;
+}
+// @snippet settings-value-helpers
+
 // @snippet qsettings-value
 // If we enter the kwds, means that we have a defaultValue or
 // at least a type.
@@ -80,61 +191,15 @@ if ((kwds && PyDict_Size(kwds) > 0) || numArgs > 1) {
 
 PyTypeObject *typeObj = reinterpret_cast<PyTypeObject*>(%PYARG_3);
 
-if (typeObj && !Shiboken::ObjectType::checkType(typeObj)) {
-    if (typeObj == &PyList_Type) {
-        QByteArray out_ba = out.toByteArray();
-        if (!out_ba.isEmpty()) {
-            QByteArrayList valuesList = out_ba.split(',');
-            const Py_ssize_t valuesSize = valuesList.size();
-            if (valuesSize > 0) {
-                PyObject *list = PyList_New(valuesSize);
-                for (Py_ssize_t i = 0; i < valuesSize; ++i) {
-                    PyObject *item = PyUnicode_FromString(valuesList.at(i).constData());
-                    PyList_SET_ITEM(list, i, item);
-                }
-                %PYARG_0 = list;
-
-            } else {
-                %PYARG_0 = %CONVERTTOPYTHON[QVariant](out);
-            }
-        } else {
-            %PYARG_0 = PyList_New(0);
-        }
-    } else if (typeObj == &PyBytes_Type) {
-        QByteArray asByteArray = out.toByteArray();
-        %PYARG_0 = PyBytes_FromString(asByteArray.constData());
-    } else if (typeObj == &PyUnicode_Type) {
-        QByteArray asByteArray = out.toByteArray();
-        %PYARG_0 = PyUnicode_FromString(asByteArray.constData());
-    } else if (typeObj == &PyLong_Type) {
-        float asFloat = out.toFloat();
-        pyResult = PyLong_FromDouble(asFloat);
-    } else if (typeObj == &PyFloat_Type) {
-        float asFloat = out.toFloat();
-        %PYARG_0 = PyFloat_FromDouble(asFloat);
-    } else if (typeObj == &PyBool_Type) {
-        if (out.toBool()) {
-            Py_INCREF(Py_True);
-            %PYARG_0 = Py_True;
-        } else {
-            Py_INCREF(Py_False);
-            %PYARG_0 = Py_False;
-        }
+if (typeObj && !Shiboken::ObjectType::checkType(typeObj)
+    && !isEquivalentSettingsType(typeObj, out.typeId())) {
+    %PYARG_0 = settingsTypeCoercion(out, typeObj);
+} else {
+    if (out.isValid()) {
+        %PYARG_0 = %CONVERTTOPYTHON[QVariant](out);
     } else {
-        // TODO: PyDict_Type and PyTuple_Type
-        PyErr_SetString(PyExc_TypeError,
-                        "Invalid type parameter.\n"
-                        "\tUse 'list', 'bytes', 'str', 'int', 'float', 'bool', "
-                        "or a Qt-derived type");
-        return nullptr;
-    }
-}
-else {
-    if (!out.isValid()) {
         Py_INCREF(Py_None);
         %PYARG_0 = Py_None;
-    } else {
-        %PYARG_0 = %CONVERTTOPYTHON[QVariant](out);
     }
 }
 
@@ -145,11 +210,7 @@ else {
 // @snippet metatype-from-type
 
 // @snippet metatype-from-metatype-type
-Shiboken::AutoDecRef intArg;
-if (usingNewEnum())
-    intArg.reset(PyObject_GetAttrString(%PYARG_1, "value"));
-else
-    intArg.reset(PyObject_CallMethod(%PYARG_1, "__int__", nullptr));
+Shiboken::AutoDecRef intArg(PyObject_GetAttrString(%PYARG_1, "value"));
 %0 = new %TYPE(PyLong_AsLong(intArg));
 // @snippet metatype-from-metatype-type
 
@@ -171,7 +232,7 @@ static QVariant QVariant_convertToVariantMap(PyObject *map)
     Py_ssize_t pos = 0;
     Shiboken::AutoDecRef keys(PyDict_Keys(map));
     if (!QVariant_isStringList(keys))
-        return QVariant();
+        return {};
     PyObject *key;
     PyObject *value;
     QMap<QString,QVariant> ret;
@@ -195,7 +256,7 @@ static QVariant QVariant_convertToVariantList(PyObject *list)
     if (PySequence_Size(list) < 0) {
         // clear the error if < 0 which means no length at all
         PyErr_Clear();
-        return QVariant();
+        return {};
     }
 
     QList<QVariant> lst;
@@ -553,7 +614,7 @@ if (ret == nullptr) {
 // @snippet qobject-sender
 
 // @snippet qbytearray-mgetitem
-if (PepIndex_Check(_key)) {
+if (PyIndex_Check(_key)) {
     const Py_ssize_t _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
     if (_i < 0 || _i >= %CPPSELF.size()) {
         PyErr_SetString(PyExc_IndexError, "index out of bounds");
@@ -594,7 +655,7 @@ return %CONVERTTOPYTHON[QByteArray](ba);
 // @snippet qbytearray-mgetitem
 
 // @snippet qbytearray-msetitem
-if (PepIndex_Check(_key)) {
+if (PyIndex_Check(_key)) {
     Py_ssize_t _i = PyNumber_AsSsize_t(_key, PyExc_IndexError);
     if (_i == -1 && PyErr_Occurred())
         return -1;
@@ -881,6 +942,13 @@ uchar *ptr = reinterpret_cast<uchar *>(Shiboken::Buffer::getPointer(%PYARG_1));
 %PYARG_0 = Shiboken::Buffer::newObject(%CPPSELF.%FUNCTION_NAME(%1, %2, %3), %2, Shiboken::Buffer::ReadWrite);
 // @snippet qfiledevice-map
 
+// @snippet qiodevice-bufferedread
+Py_ssize_t bufferLen;
+auto *data = reinterpret_cast<char*>(Shiboken::Buffer::getPointer(%PYARG_1, &bufferLen));
+%RETURN_TYPE %0 = %CPPSELF.%FUNCTION_NAME(data, PyLong_AsLongLong(%PYARG_2));
+return PyLong_FromLong(%0);
+// @snippet qiodevice-bufferedread
+
 // @snippet qiodevice-readdata
 QByteArray ba(1 + qsizetype(%2), char(0));
 %CPPSELF.%FUNCTION_NAME(ba.data(), qint64(%2));
@@ -985,6 +1053,43 @@ Py_XDECREF(pyTimer);
 timer->start(%1);
 // @snippet qtimer-singleshot-2
 
+// @snippet qtimer-singleshot-functor-context
+Shiboken::AutoDecRef emptyTuple(PyTuple_New(0));
+if (PyObject_TypeCheck(%3, PySideSignalInstance_TypeF())) {
+    auto *timerType = Shiboken::SbkType<QTimer>();
+    auto *pyTimer = timerType->tp_new(Shiboken::SbkType<QTimer>(), emptyTuple, nullptr);
+    timerType->tp_init(pyTimer, emptyTuple, nullptr);
+    QTimer * timer = %CONVERTTOCPP[QTimer *](pyTimer);
+    timer->setSingleShot(true);
+    PySideSignalInstance *signalInstance = reinterpret_cast<PySideSignalInstance *>(%2);
+    Shiboken::AutoDecRef signalSignature(Shiboken::String::fromFormat("2%s", PySide::Signal::getSignature(signalInstance)));
+    Shiboken::AutoDecRef result(
+        PyObject_CallFunction(PySide::PySideName::qtConnect(), "OsOO",
+                              pyTimer,
+                              SIGNAL(timeout()),
+                              %3,
+                              PySide::Signal::getObject(signalInstance),
+                              signalSignature.object())
+    );
+    timer->connect(timer, &QTimer::timeout, timer, &QObject::deleteLater, Qt::DirectConnection);
+    Shiboken::Object::releaseOwnership(reinterpret_cast<SbkObject *>(pyTimer));
+    Py_XDECREF(pyTimer);
+    timer->start(%1);
+} else {
+    auto *callable = %PYARG_3;
+    auto cppCallback = [callable]()
+    {
+        Shiboken::GilState state;
+        Shiboken::AutoDecRef arglist(PyTuple_New(0));
+        Shiboken::AutoDecRef ret(PyObject_CallObject(callable, arglist));
+        Py_DECREF(callable);
+    };
+
+    Py_INCREF(callable);
+    %CPPSELF.%FUNCTION_NAME(%1, %2, cppCallback);
+}
+// @snippet qtimer-singleshot-functor-context
+
 // @snippet qprocess-startdetached
 qint64 pid;
 %RETURN_TYPE retval = %TYPE::%FUNCTION_NAME(%1, %2, %3, &pid);
@@ -1049,6 +1154,16 @@ if (result == -1) {
 }
 // @snippet qdatastream-readrawdata
 
+// @snippet qdatastream-writerawdata-pybuffer
+int r = 0;
+Py_ssize_t bufferLen;
+auto *data = reinterpret_cast<const char*>(Shiboken::Buffer::getPointer(%PYARG_1, &bufferLen));
+Py_BEGIN_ALLOW_THREADS
+r = %CPPSELF.%FUNCTION_NAME(data, bufferLen);
+Py_END_ALLOW_THREADS
+%PYARG_0 = %CONVERTTOPYTHON[int](r);
+// @snippet qdatastream-writerawdata-pybuffer
+
 // @snippet qdatastream-writerawdata
 int r = 0;
 Py_BEGIN_ALLOW_THREADS
@@ -1187,7 +1302,7 @@ Py_END_ALLOW_THREADS
     if (atexit.isNull()) {
         qWarning("Module atexit not found for registering __moduleShutdown");
         PyErr_Clear();
-    }else{
+    } else {
         regFunc.reset(PyObject_GetAttrString(atexit, "register"));
         if (regFunc.isNull()) {
             qWarning("Function atexit.register not found for registering __moduleShutdown");
@@ -1550,13 +1665,17 @@ pthread_cleanup_pop(0);
 // @snippet qthread_pthread_cleanup_uninstall
 
 // @snippet qlibraryinfo_build
-#if defined(Py_LIMITED_API)
-auto suffix = PyUnicode_FromString(" [limited API]");
 auto oldResult = pyResult;
-pyResult = PyUnicode_Concat(pyResult, suffix);
-Py_DECREF(oldResult);
-Py_DECREF(suffix);
+const auto version = _PepRuntimeVersion();
+pyResult = PyUnicode_FromFormat(
+#ifdef Py_LIMITED_API
+                                "%U [Python limited API %d.%d.%d]",
+#else
+                                "%U [Python %d.%d.%d]",
 #endif
+                                oldResult, (version >> 16) & 0xFF,
+                                (version >> 8) & 0xFF, version & 0xFF);
+Py_DECREF(oldResult);
 // @snippet qlibraryinfo_build
 
 // @snippet qsharedmemory_data_readonly
@@ -1668,95 +1787,114 @@ QtCoreHelper::QGenericReturnArgumentHolder result(qArgData.metaType, qArgData.da
 %PYARG_0 = %CONVERTTOPYTHON[QtCoreHelper::QGenericReturnArgumentHolder](result);
 // @snippet q_return_arg
 
+// @snippet qmetamethod-invoke-helpers
+static InvokeMetaMethodFunc
+    createInvokeMetaMethodFunc(const QMetaMethod &method, QObject *object,
+                               Qt::ConnectionType type = Qt::AutoConnection)
+{
+    return [&method, object, type](QGenericArgument a0, QGenericArgument a1,
+                                   QGenericArgument a2, QGenericArgument a3,
+                                   QGenericArgument a4, QGenericArgument a5,
+                                   QGenericArgument a6, QGenericArgument a7,
+                                   QGenericArgument a8, QGenericArgument a9) -> bool
+    {
+        return method.invoke(object, type, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
+    };
+}
+
+static InvokeMetaMethodFuncWithReturn
+    createInvokeMetaMethodFuncWithReturn(const QMetaMethod &method, QObject *object,
+                                         Qt::ConnectionType type = Qt::AutoConnection)
+{
+    return [&method, object, type](QGenericReturnArgument r,
+                                   QGenericArgument a0, QGenericArgument a1,
+                                   QGenericArgument a2, QGenericArgument a3,
+                                   QGenericArgument a4, QGenericArgument a5,
+                                   QGenericArgument a6, QGenericArgument a7,
+                                   QGenericArgument a8, QGenericArgument a9) -> bool
+    {
+        return method.invoke(object, type, r, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
+    };
+}
+// @snippet qmetamethod-invoke-helpers
+
+// @snippet qmetamethod-invoke-conn-type-return-arg
+%PYARG_0 = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(*%CPPSELF, %1, %2),
+                                      %3, %4, %5, %6, %7, %8, %9, %10, %11, %12, %13);
+// @snippet qmetamethod-invoke-conn-type-return-arg
+
+// @snippet qmetamethod-invoke-return-arg
+%PYARG_0 = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(*%CPPSELF, %1),
+                                      %2, %3, %4, %5, %6, %7, %8, %9, %10, %11, %12);
+// @snippet qmetamethod-invoke-return-arg
+
+// @snippet qmetamethod-invoke-conn-type
+%PYARG_0 = invokeMetaMethod(createInvokeMetaMethodFunc(*%CPPSELF, %1, %2),
+                            %3, %4, %5, %6, %7, %8, %9, %10, %11, %12);
+// @snippet qmetamethod-invoke-conn-type
+
+// @snippet qmetamethod-invoke
+%PYARG_0 = invokeMetaMethod(createInvokeMetaMethodFunc(*%CPPSELF, %1),
+                            %2, %3, %4, %5, %6, %7, %8, %9, %10, %11);
+// @snippet qmetamethod-invoke
+
+// @snippet qmetaobject-invokemethod-helpers
+static InvokeMetaMethodFunc
+    createInvokeMetaMethodFunc(QObject *object, const char *methodName,
+                               Qt::ConnectionType type = Qt::AutoConnection)
+{
+    return [object, methodName, type](QGenericArgument a0, QGenericArgument a1,
+                                      QGenericArgument a2, QGenericArgument a3,
+                                      QGenericArgument a4, QGenericArgument a5,
+                                      QGenericArgument a6, QGenericArgument a7,
+                                      QGenericArgument a8, QGenericArgument a9) -> bool
+    {
+        return QMetaObject::invokeMethod(object, methodName, type,
+                                         a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
+    };
+}
+
+static InvokeMetaMethodFuncWithReturn
+    createInvokeMetaMethodFuncWithReturn(QObject *object, const char *methodName,
+                                         Qt::ConnectionType type = Qt::AutoConnection)
+{
+    return [object, methodName, type](QGenericReturnArgument r,
+                                      QGenericArgument a0, QGenericArgument a1,
+                                      QGenericArgument a2, QGenericArgument a3,
+                                      QGenericArgument a4, QGenericArgument a5,
+                                      QGenericArgument a6, QGenericArgument a7,
+                                      QGenericArgument a8, QGenericArgument a9) -> bool
+    {
+        return QMetaObject::invokeMethod(object, methodName, type,
+                                         r, a0, a1, a2, a3, a4, a5, a6, a7, a8, a9);
+    };
+}
+// @snippet qmetaobject-invokemethod-helpers
+
 // invokeMethod(QObject *,const char *, QGenericArgument a0, a1, a2 )
 // @snippet qmetaobject-invokemethod-arg
-PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
-const bool result = %CPPSELF.invokeMethod(%1, %2, %3.toGenericArgument(), %4.toGenericArgument(),
-                                          %5.toGenericArgument());
-PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
-%PYARG_0 = %CONVERTTOPYTHON[bool](result);
+%PYARG_0 = invokeMetaMethod(createInvokeMetaMethodFunc(%1, %2),
+                            %3, %4, %5, %6, %7, %8, %9, %10, %11, %12);
 // @snippet qmetaobject-invokemethod-arg
 
 // invokeMethod(QObject *,const char *,Qt::ConnectionType, QGenericArgument a0, a1, a2 )
 // @snippet qmetaobject-invokemethod-conn-type-arg
-PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
-const bool result = %CPPSELF.invokeMethod(%1, %2, %3,
-                                          %4.toGenericArgument(), %5.toGenericArgument(),
-                                          %6.toGenericArgument());
-PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
-%PYARG_0 = %CONVERTTOPYTHON[bool](result);
+%PYARG_0 = invokeMetaMethod(createInvokeMetaMethodFunc(%1, %2, %3),
+                             %4, %5, %6, %7, %8, %9, %10, %11, %12, %13);
 // @snippet qmetaobject-invokemethod-conn-type-arg
 
-// @snippet qmetaobject-invokemethod-helpers
-static PyObject *invokeMethodHelper(QObject *obj, const char *member, Qt::ConnectionType type,
-                                    const QtCoreHelper::QGenericReturnArgumentHolder &returnArg,
-                                    const QtCoreHelper::QGenericArgumentHolder &v1,
-                                    const QtCoreHelper::QGenericArgumentHolder &v2,
-                                    const QtCoreHelper::QGenericArgumentHolder &v3)
-
-{
-    PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
-    const bool callResult = QMetaObject::invokeMethod(obj, member, type,
-                                                      returnArg.toGenericReturnArgument(),
-                                                      v1.toGenericArgument(), v2.toGenericArgument(),
-                                                      v3.toGenericArgument());
-    PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
-    if (!callResult) {
-        PyErr_Format(PyExc_RuntimeError, "QMetaObject::invokeMethod(): Invocation of %s::%s() failed.",
-                     obj->metaObject()->className(), member);
-        return nullptr;
-    }
-
-    PyObject *result = nullptr;
-    const void *retData = returnArg.data();
-    const QMetaType metaType = returnArg.metaType();
-    switch (metaType.id()) {
-    case QMetaType::Bool:
-        result = *reinterpret_cast<const bool *>(retData) ? Py_True : Py_False;
-        Py_INCREF(result);
-        break;
-    case QMetaType::Int:
-        result = PyLong_FromLong(*reinterpret_cast<const int *>(retData));
-        break;
-    case QMetaType::Double:
-        result = PyFloat_FromDouble(*reinterpret_cast<const double *>(retData));
-        break;
-    case QMetaType::QString:
-        result = PySide::qStringToPyUnicode(*reinterpret_cast<const QString *>(retData));
-        break;
-    default: {
-        Shiboken::Conversions::SpecificConverter converter(metaType.name());
-        const auto type = converter.conversionType();
-        if (type == Shiboken::Conversions::SpecificConverter::InvalidConversion) {
-            PyErr_Format(PyExc_RuntimeError, "%s: Unable to find converter for \"%s\".",
-                         __FUNCTION__, metaType.name());
-            return nullptr;
-        }
-        result = converter.toPython(retData);
-    }
-    }
-    return result;
-}
-// @snippet qmetaobject-invokemethod-helpers
-
 // invokeMethod(QObject *,const char *, Qt::ConnectionType, QGenericReturnArgument,QGenericArgument a0, a1, a2 )
 // @snippet qmetaobject-invokemethod-conn-type-return-arg
-%PYARG_0 = invokeMethodHelper(%1, %2, %3, %4, %5, %6, %7);
+%PYARG_0 = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(%1, %2, %3),
+                                      %4, %5, %6, %7, %8, %9, %10, %11, %12, %13, %14);
 // @snippet qmetaobject-invokemethod-conn-type-return-arg
 
 // invokeMethod(QObject *,const char *, QGenericReturnArgument,QGenericArgument a0, a1, a2 )
 // @snippet qmetaobject-invokemethod-return-arg
-%PYARG_0 = invokeMethodHelper(%1, %2, Qt::AutoConnection, %3, %4, %5, %6);
+%PYARG_0 = invokeMetaMethodWithReturn(createInvokeMetaMethodFuncWithReturn(%1, %2),
+                                      %3, %4, %5, %6, %7, %8, %9, %10, %11, %12, %13);
 // @snippet qmetaobject-invokemethod-return-arg
 
-// @snippet qabstractitemmodel_data
-::QVariant %0;
-if (Shiboken::Enum::check(%PYARG_0))
-    %0 = QVariant(int(Shiboken::Enum::getValue(%PYARG_0)));
-else
-    pythonToCpp(pyResult, &cppResult);
-// @snippet qabstractitemmodel_data
-
 // @snippet keycombination-from-keycombination
 cptr = new ::%TYPE(%1);
 // @snippet keycombination-from-keycombination
@@ -1767,12 +1905,10 @@ cptr = new ::%TYPE(%1, %2);
 
 // @snippet qmetamethod-from-signal
 auto *signalInst = reinterpret_cast<PySideSignalInstance *>(%PYARG_1);
-PyObject *emitterPyObject = PySide::Signal::getObject(signalInst);
-QObject* emitter = %CONVERTTOCPP[QObject *](emitterPyObject);
-const QByteArray signature = PySide::Signal::getSignature(signalInst);
-const auto *mo = emitter->metaObject();
-const auto index = mo->indexOfSignal(signature.constData());
-const auto result = index != -1 ? mo->method(index) : QMetaMethod{};
+const auto data = PySide::Signal::getEmitterData(signalInst);
+const auto result = data.methodIndex != -1
+    ? data.emitter->metaObject()->method(data.methodIndex)
+    : QMetaMethod{};
 %PYARG_0 = %CONVERTTOPYTHON[QMetaMethod](result);
 // @snippet qmetamethod-from-signal
 
@@ -1791,4 +1927,97 @@ auto callback = [callable]() -> void
 Py_INCREF(callable);
 %RETURN_TYPE %0 = %CPPSELF.%FUNCTION_NAME(callback);
 %PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
-// @snipped qrunnable_create
+// @snippet qrunnable_create
+
+// @snippet qlocale_system
+// For darwin systems, QLocale::system() involves looking at the Info.plist of the application
+// bundle to detect the system localization. In the case of Qt for Python, the application bundle
+// is the used Python framework. To enable retreival of localized string, the property list key
+// CFBunldeAllowMixedLocalizations should be set to True inside the Info.plist file. Otherwise,
+// CFBundleDevelopmentRegion will be used to find the language preference of the user, which in the
+// case of Python is always english.
+// This is a hack until CFBunldeAllowMixedLocalizations will be set in the Python framework
+// installation in darwin systems.
+// Upstream issue in CPython: https://github.com/python/cpython/issues/108269
+#ifdef Q_OS_DARWIN
+    Shiboken::AutoDecRef locale(PyImport_ImportModule("locale"));
+    Shiboken::AutoDecRef getLocale(PyObject_GetAttrString(locale, "getlocale"));
+    Shiboken::AutoDecRef systemLocale(PyObject_CallObject(getLocale, nullptr));
+    Shiboken::AutoDecRef localeCode(PyTuple_GetItem(systemLocale, 0));
+    %RETURN_TYPE %0;
+    if (localeCode != Py_None) {
+        QString localeCodeStr = PySide::pyStringToQString(localeCode);
+        %0 = QLocale(localeCodeStr);
+    } else {
+       // The default locale is 'C' locale as mentioned in
+       // https://docs.python.org/3/library/locale.html
+        %0 = ::QLocale::c();
+    }
+#else
+    %RETURN_TYPE %0 = %CPPSELF.%FUNCTION_NAME();
+#endif
+%PYARG_0 = %CONVERTTOPYTHON[%RETURN_TYPE](%0);
+// @snippet qlocale_system
+
+// @snippet qcoreapplication-requestpermission
+auto permission = %1;
+auto callable = %PYARG_3;
+
+// check if callable
+if (!PyCallable_Check(callable)) {
+    qWarning("Functor of %FUNCTION_NAME is not a callable");
+    return {};
+}
+
+// find the number of arguments of callable. It should either be empy or accept a QPermission
+// object
+int count = 0;
+PyObject* fc = nullptr;
+bool classMethod = false;
+Shiboken::AutoDecRef func_ob(PyObject_GetAttr(callable, Shiboken::PyMagicName::func()));
+
+if (func_ob.isNull() && PyObject_HasAttr(callable, Shiboken::PyMagicName::code())) {
+    // variable `callable` is a function
+    fc = PyObject_GetAttr(callable, Shiboken::PyMagicName::code());
+} else {
+    // variable `callable` is a class method
+    fc = PyObject_GetAttr(func_ob, Shiboken::PyMagicName::code());
+    classMethod = true;
+}
+
+if (fc) {
+    PyObject* ac = PyObject_GetAttrString(fc, "co_argcount");
+    if (ac) {
+        count = PyLong_AsLong(ac);
+        Py_DECREF(ac);
+    }
+    Py_DECREF(fc);
+}
+
+if ((classMethod && (count > 2)) || (!classMethod && (count > 1))) {
+    qWarning("Functor of %FUNCTION_NAME must either have QPermission object as argument or none."
+             "The QPermission object store the result of requestPermission()");
+    return {};
+}
+
+bool arg_qpermission = (classMethod && (count == 2)) || (!classMethod && (count == 1));
+
+auto callback = [callable, count, arg_qpermission](const QPermission &permission) -> void
+{
+    Shiboken::GilState state;
+    if (arg_qpermission) {
+        Shiboken::AutoDecRef arglist(PyTuple_New(1));
+        PyTuple_SET_ITEM(arglist.object(), 0, %CONVERTTOPYTHON[QPermission](permission));
+        PyObject_CallObject(callable, arglist);
+    } else {
+        PyObject_CallObject(callable, nullptr);
+    }
+    Py_DECREF(callable);
+};
+Py_INCREF(callable);
+
+Py_BEGIN_ALLOW_THREADS
+%CPPSELF.%FUNCTION_NAME(permission, %2, callback);
+Py_END_ALLOW_THREADS
+// @snippet qcoreapplication-requestpermission
+
