@@ -313,10 +313,7 @@ if (_i < 0 || _i >= %CPPSELF.count()) {
     return 0;
 }
 QKeyCombination item = (*%CPPSELF)[_i];
-if (usingNewEnum())
-    return %CONVERTTOPYTHON[QKeyCombination](item);
-auto combined = item.toCombined();
-return %CONVERTTOPYTHON[int](combined);
+return %CONVERTTOPYTHON[QKeyCombination](item);
 // @snippet qkeysequence-getitem
 
 // @snippet qkeysequence-repr
@@ -374,6 +371,16 @@ const auto path = PySide::pyPathToQString(%PYARG_1);
 %CPPSELF->addPixmap(path);
 // @snippet qicon-addpixmap
 
+// @snippet qclipboard-setpixmap
+const auto path = PySide::pyPathToQString(%PYARG_1);
+%CPPSELF->setPixmap(QPixmap(path));
+// @snippet qclipboard-setpixmap
+
+// @snippet qclipboard-setimage
+const auto path = PySide::pyPathToQString(%PYARG_1);
+%CPPSELF->setImage(QImage(path));
+// @snippet qclipboard-setimage
+
 // @snippet qimage-decref-image-data
 static void imageDecrefDataHandler(void *data)
 {
@@ -861,6 +868,17 @@ const QRect cppResult = *(%CPPSELF.cbegin() + _i);
 return %CONVERTTOPYTHON[QRect](cppResult);
 // @snippet qregion-getitem
 
+// Some RHI functions take a std::initializer_list<>. Add functions
+// to convert from list.
+
+// @snippet qrhi-initializer-list
+%CPPSELF.%FUNCTION_NAME(%1.cbegin(), %1.cend());
+// @snippet qrhi-initializer-list
+
+// @snippet qrhi-commandbuffer-setvertexinput
+%CPPSELF.%FUNCTION_NAME(%1, %2.size(), %2.constData(), %3, %4, %5);
+// @snippet qrhi-commandbuffer-setvertexinput
+
 /*********************************************************************
  * CONVERSIONS
  ********************************************************************/
